@@ -10,10 +10,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-
-from heatclient.tests.functional.osc.v1 import base
 from tempest.lib.common.utils import data_utils as utils
 
+from heatclient.tests.functional import config
+from heatclient.tests.functional.osc.v1 import base
+
 
 class OpenStackClientStackTest(base.OpenStackClientTestBase):
     """Basic stack operation tests for Openstack CLI client heat plugin.
@@ -25,16 +26,25 @@ class OpenStackClientStackTest(base.OpenStackClientTestBase):
         super(OpenStackClientStackTest, self).setUp()
         self.stack_name = utils.rand_name(name='test-stack')
 
-    def _stack_create_minimal(self):
-        template = self.get_template_path('heat_minimal_hot.yaml')
+    def _stack_create_minimal(self, from_url=False):
+        if from_url:
+            template = config.HEAT_MINIMAL_HOT_TEMPLATE_URL
+        else:
+            template = self.get_template_path('heat_minimal_hot.yaml')
         parameters = ['test_client_name=test_client_name']
-        return self._stack_create(self.stack_name, template, parameters)
+        return self._stack_create(self.stack_name, template=template,
+                                  parameters=parameters)
 
-    def test_stack_create_minimal(self):
+    def test_stack_create_minimal_from_file(self):
         stack = self._stack_create_minimal()
         self.assertEqual(self.stack_name, stack['stack_name'])
         self.assertEqual("CREATE_COMPLETE", stack['stack_status'])
 
+    def test_stack_create_minimal_from_url(self):
+        stack = self._stack_create_minimal(from_url=True)
+        self.assertEqual(self.stack_name, stack['stack_name'])
+        self.assertEqual("CREATE_COMPLETE", stack['stack_status'])
+
     def test_stack_suspend_resume(self):
         stack = self._stack_create_minimal()
         stack = self._stack_suspend(stack['id'])
@@ -50,3 +60,9 @@ class OpenStackClientStackTest(base.OpenStackClientTestBase):
         snapshot = self._stack_snapshot_create(stack['id'], snapshot_name)
         self.assertEqual(snapshot_name, snapshot['name'])
         self._stack_snapshot_restore(stack['id'], snapshot['id'])
+
+    def test_stack_delete(self):
+        stack = self._stack_create_minimal()
+        self._stack_delete(stack['id'])
+        stacks_raw = self.openstack('stack list')
+        self.assertNotIn(stack['id'], stacks_raw)
